==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/GetWebAppSitesControllerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 * @property webAppSiteName Web app site name.
 */
public data class GetWebAppSitesControllerPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
    public val webAppSiteName: String,
) : ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs =
        com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 }))
            .webAppSiteName(webAppSiteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWebAppSitesControllerPlainArgs].
 */
@PulumiTagMarker
public class GetWebAppSitesControllerPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    private var webAppSiteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("piwcghqfxwwnllwt")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("denwyofoudorvtng")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    /**
     * @param value Web app site name.
     */
    @JvmName("xmpxskolobwviisr")
    public suspend fun webAppSiteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.webAppSiteName = mapped
    }

    internal fun build(): GetWebAppSitesControllerPlainArgs = GetWebAppSitesControllerPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        webAppSiteName = webAppSiteName ?: throw PulumiNullFieldException("webAppSiteName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/offazure/kotlin/inputs/GetWebAppSitesControllerPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.offazure.kotlin.inputs

import com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property siteName Site name
 * @property webAppSiteName Web app site name.
 */
public data class GetWebAppSitesControllerPlainArgs(
    public val resourceGroupName: String,
    public val siteName: String,
    public val webAppSiteName: String,
) : ConvertibleToJava<com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs =
        com.pulumi.azurenative.offazure.inputs.GetWebAppSitesControllerPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .siteName(siteName.let({ args0 -> args0 }))
            .webAppSiteName(webAppSiteName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetWebAppSitesControllerPlainArgs].
 */
@PulumiTagMarker
public class GetWebAppSitesControllerPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var siteName: String? = null

    private var webAppSiteName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("lllrtngrtspyfhur")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Site name
     */
    @JvmName("vhvkouwgmrapspbj")
    public suspend fun siteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.siteName = mapped
    }

    /**
     * @param value Web app site name.
     */
    @JvmName("wialpmxwpaqnnwdh")
    public suspend fun webAppSiteName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.webAppSiteName = mapped
    }

    internal fun build(): GetWebAppSitesControllerPlainArgs = GetWebAppSitesControllerPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        siteName = siteName ?: throw PulumiNullFieldException("siteName"),
        webAppSiteName = webAppSiteName ?: throw PulumiNullFieldException("webAppSiteName"),
    )
}
